changeset 24586:b7f58be68c02 v8.2.2832

patch 8.2.2832: operator cancelled by moving mouse when using popup Commit: https://github.com/vim/vim/commit/1ad72c8eb601d681c84b47380fc31b6d23602d51 Author: Bram Moolenaar <Bram@vim.org> Date: Tue May 4 21:56:28 2021 +0200 patch 8.2.2832: operator cancelled by moving mouse when using popup Problem: Operator cancelled by moving mouse when using popup. (Sergey Vlasov) Solution: Do not trigger an operator for a mouse move events. (closes #8176)
author Bram Moolenaar <Bram@vim.org>
date Tue, 04 May 2021 22:00:06 +0200
parents 2cbf16b37b92
children c41f3377f32f
files src/normal.c src/version.c
diffstat 2 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -751,6 +751,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    2832,
+/**/
     2831,
 /**/
     2830,
--- a/src/normal.c
+++ b/src/normal.c
@@ -1119,9 +1119,10 @@ getcount:
 	old_mapped_len = typebuf_maplen();
 
     /*
      * If an operation is pending, handle it.  But not for K_IGNORE.
      */
-    if (ca.cmdchar != K_IGNORE)
+    if (ca.cmdchar != K_IGNORE && ca.cmdchar != K_MOUSEMOVE)
 	do_pending_operator(&ca, old_col, FALSE);
 
     /*
@@ -1119,9 +1119,10 @@ getcount:
 
     /*
-     * If an operation is pending, handle it.  But not for K_IGNORE.
+     * If an operation is pending, handle it.  But not for K_IGNORE or
+     * K_MOUSEMOVE.
      */